@@ -32,6 +32,7 @@ function QueueListModel(parent) {
     // External var's
     self.queueItems = ko.observableArray([]);
     self.totalItems = ko.observable(0);
+    self.deleteItems = ko.observableArray([]);
     self.isMultiEditing = ko.observable(false).extend({ persist: 'queueIsMultiEditing' });
     self.isLoading = ko.observable(false).extend({ rateLimit: 100 });
     self.multiEditItems = ko.observableArray([]);
@@ -147,6 +148,27 @@ function QueueListModel(parent) {
 
     }
 
+    self.triggerRemoveDownload = function(items) {
+        // Show and fill modal
+        self.deleteItems.removeAll()
+
+        // Single or multiple items?
+        if(items.length) {
+            ko.utils.arrayPushAll(self.deleteItems, items)
+        } else {
+            self.deleteItems.push(items)
+        }
+
+        // Show modal or delete right away
+        if(self.parent.confirmDeleteQueue()) {
+            // Open modal if desired
+            $('#modal-delete-queue-job').modal("show")
+        } else {
+            // Otherwise just submit right away
+            $('#modal-delete-queue-job form').submit()
+        }
+    }
+
     // Save pagination state
     self.paginationLimit.subscribe(function(newValue) {
         // Save in config if global
@@ -401,42 +423,103 @@ function QueueListModel(parent) {
 
     }
 
+    // Handle mousedown to capture state before change
+    self.handleMultiEditStatusMouseDown = function(item, event) {
+        var clickedValue = $(event.currentTarget).find("input").val();
+
+        // If this radio was already selected (same value as previous), clear it
+        if ($('.multioperations-selector input[name="multiedit-status"]:checked').val() === clickedValue) {
+            // Clear all radio buttons in this group after the click finished
+            // Hacky, but it works
+            setTimeout(function () {
+                $('.multioperations-selector input[name="multiedit-status"]').prop('checked', false);
+            }, 200)
+        }
+        return true;
+    }
+
+    // Remove downloads from queue
+    self.removeDownloads = function(form) {
+        // Hide modal and show notification
+        $('#modal-delete-queue-job').modal("hide")
+        showNotification('.main-notification-box-removing')
+
+        var strIDs = '';
+        $.each(self.deleteItems(), function(index) {
+            strIDs = strIDs + this.id + ',';
+        })
+
+        callAPI({
+            mode: 'queue',
+            name: 'delete',
+            del_files: 1,
+            value: strIDs
+        }).then(function(response) {
+            self.queueItems.removeAll(self.deleteItems());
+            self.multiEditItems.removeAll(self.deleteItems())
+            self.parent.refresh();
+            hideNotification()
+        });
+    };
+
     // Delete all selected
     self.doMultiDelete = function() {
         // Anything selected?
         if(self.multiEditItems().length < 1) return;
 
-        // Need confirm
-        if(!self.parent.confirmDeleteQueue() || confirm(glitterTranslate.removeDown)) {
-            // List all the ID's
-            var strIDs = '';
-            $.each(self.multiEditItems(), function(index) {
-                strIDs = strIDs + this.id + ',';
-            })
-
-            // Show notification
-            showNotification('.main-notification-box-removing-multiple', 0, self.multiEditItems().length)
-
-            // Remove
-            callAPI({
-                mode: 'queue',
-                name: 'delete',
-                del_files: 1,
-                value: strIDs
-            }).then(function(response) {
-                if(response.status) {
-                    // Make sure the queue doesnt flicker and then fade-out
-                    self.isLoading(true)
-                    self.parent.refresh()
-                    // Empty it
-                    self.multiEditItems.removeAll();
-                    // Hide notification
-                    hideNotification()
-                }
-            })
-        }
+        // Trigger modal
+        self.triggerRemoveDownload(self.multiEditItems())
     }
 
+    // Move all selected to top
+    self.doMultiMoveToTop = function() {
+        // Anything selected?
+        if(self.multiEditItems().length < 1) return;
+
+        // Move each item to the top, starting from the last one in the sorted list
+        var arrayList = self.multiEditItems()
+        var movePromises = [];
+        for(var i = arrayList.length - 1; i >= 0; i--) {
+            movePromises.push(callAPI({
+                mode: "switch",
+                value: arrayList[i].id,
+                value2: 0
+            }));
+        }
+
+        // Wait for all moves to complete then refresh
+        Promise.all(movePromises).then(function() {
+            self.parent.refresh();
+        });
+    }
+
+    // Move all selected to bottom
+    self.doMultiMoveToBottom = function() {
+        // Anything selected?
+        if(self.multiEditItems().length < 1) return;
+
+        // Move each item to the bottom, starting from the first one in the sorted list
+        var arrayList = self.multiEditItems()
+        var movePromises = [];
+        for(var i = 0; i < arrayList.length; i++) {
+            movePromises.push(callAPI({
+                mode: "switch",
+                value: arrayList[i].id,
+                value2: self.totalItems() - 1
+            }));
+        }
+
+        // Wait for all moves to complete then refresh
+        Promise.all(movePromises).then(function() {
+            self.parent.refresh();
+        });
+    }
+
+    // Focus on the confirm button
+    $('#modal-delete-queue-job').on("shown.bs.modal", function() {
+        $('#modal-delete-queue-job .btn[type="submit"]').focus()
+    })
+
     // On change of page we need to check all those that were in the list!
     self.queueItems.subscribe(function() {
         // We need to wait until the unit is actually finished rendering
@@ -627,9 +710,37 @@ function QueueModel(parent, data) {
         self.editingName(true)
         self.nameForEdit(self.name())
 
-        // Select
-        $(event.target).parents('.name').find('input').select()
-    }
+        // Select the input
+        const $input = $(event.target).parents('.name').find('input');
+        $input.select();
+
+        // Add Tab/Shift+Tab navigation
+        $input.off('keydown.tabnav').on('keydown.tabnav', function (e) {
+            if (e.key === 'Tab') {
+                e.preventDefault();
+
+                // Find all rename inputs that are currently visible
+                const inputs = $('.queue-table input[type="text"]');
+                const currentIndex = inputs.index(this);
+                let nextIndex = e.shiftKey ? currentIndex - 1 : currentIndex + 1;
+
+                // Wrap around
+                if (nextIndex >= inputs.length) nextIndex = 0;
+                if (nextIndex < 0) nextIndex = inputs.length - 1;
+
+                // Simulate clicking Rename on the next row
+                const $nextRow = inputs.eq(nextIndex).closest('tr');
+                $nextRow.find('.hover-button[title="Rename"]').click();
+
+                // Delay focusing to wait for new input to appear
+                setTimeout(() => {
+                    const $nextInput = $('.queue-table input[type="text"]').eq(nextIndex);
+                    $nextInput.focus().select();
+                }, 50);
+            }
+        });
+    };
+
 
     // Catch the submit action
     self.editingNameSubmit = function() {
@@ -711,29 +822,5 @@ function QueueModel(parent, data) {
         })
     }
 
-    // Remove 1 download from queue
-    self.removeDownload = function(item, event) {
-        // Confirm and remove
-        if(!self.parent.parent.confirmDeleteQueue() || confirm(glitterTranslate.deleteMsg + ":\n" + item.name() + "\n\n" + glitterTranslate.removeDow1)) {
-            var itemToDelete = this;
 
-            // Show notification
-            showNotification('.main-notification-box-removing')
-
-            callAPI({
-                mode: 'queue',
-                name: 'delete',
-                del_files: 1,
-                value: item.id
-            }).then(function(response) {
-                // Make sure no flickering (if there are more items left) and then remove
-                self.parent.isLoading(self.parent.totalItems() > 1)
-                parent.queueItems.remove(itemToDelete);
-                parent.multiEditItems.remove(function(inList) { return inList.id === itemToDelete.id; })
-                self.parent.parent.refresh();
-                // Hide notifcation
-                hideNotification()
-            });
-        }
-    };
 }
