@@ -185,7 +185,7 @@ def validate_host(value: str) -> ValidateResult:
         ipaddress.ip_address(value)
         # valid host, so return it
         return None, value
-    except:
+    except Exception:
         pass
 
     # we don't want a plain number. As socket.getaddrinfo("100", ...) allows that, we have to pre-check
@@ -193,7 +193,7 @@ def validate_host(value: str) -> ValidateResult:
         int(value)
         # plain int as input, which is not allowed
         return T("Invalid server address."), None
-    except:
+    except Exception:
         pass
 
     # not a plain IPv4 nor IPv6 address, so let's check if it's a name that resolves to IPv4
@@ -202,7 +202,7 @@ def validate_host(value: str) -> ValidateResult:
         # all good
         logging.debug("Valid host name")
         return None, value
-    except:
+    except Exception:
         pass
 
     # ... and if not: does it resolve to IPv6 ... ?
@@ -211,7 +211,7 @@ def validate_host(value: str) -> ValidateResult:
         # all good
         logging.debug("Valid host name")
         return None, value
-    except:
+    except Exception:
         logging.debug("No valid host name")
         pass
 
@@ -531,6 +531,7 @@ switchinterval = OptionNumber("misc", "switchinterval", 0.005, minval=0.001)
 ssdp_broadcast_interval = OptionNumber("misc", "ssdp_broadcast_interval", 15, minval=1, maxval=600)
 ext_rename_ignore = OptionList("misc", "ext_rename_ignore", validation=lower_case_ext)
 unrar_parameters = OptionStr("misc", "unrar_parameters", validation=supported_unrar_parameters)
+outgoing_nntp_ip = OptionStr("misc", "outgoing_nntp_ip")
 
 
 ##############################################################################
@@ -558,6 +559,7 @@ ncenter_prio_pp = OptionBool("ncenter", "ncenter_prio_pp", False)
 ncenter_prio_complete = OptionBool("ncenter", "ncenter_prio_complete", True)
 ncenter_prio_failed = OptionBool("ncenter", "ncenter_prio_failed", True)
 ncenter_prio_disk_full = OptionBool("ncenter", "ncenter_prio_disk_full", True)
+ncenter_prio_quota = OptionBool("ncenter", "ncenter_prio_quota", True)
 ncenter_prio_new_login = OptionBool("ncenter", "ncenter_prio_new_login", False)
 ncenter_prio_warning = OptionBool("ncenter", "ncenter_prio_warning", False)
 ncenter_prio_error = OptionBool("ncenter", "ncenter_prio_error", False)
@@ -574,6 +576,7 @@ acenter_prio_pp = OptionBool("acenter", "acenter_prio_pp", False)
 acenter_prio_complete = OptionBool("acenter", "acenter_prio_complete", True)
 acenter_prio_failed = OptionBool("acenter", "acenter_prio_failed", True)
 acenter_prio_disk_full = OptionBool("acenter", "acenter_prio_disk_full", True)
+acenter_prio_quota = OptionBool("acenter", "acenter_prio_quota", True)
 acenter_prio_new_login = OptionBool("acenter", "acenter_prio_new_login", False)
 acenter_prio_warning = OptionBool("acenter", "acenter_prio_warning", False)
 acenter_prio_error = OptionBool("acenter", "acenter_prio_error", False)
@@ -590,6 +593,7 @@ ntfosd_prio_pp = OptionBool("ntfosd", "ntfosd_prio_pp", False)
 ntfosd_prio_complete = OptionBool("ntfosd", "ntfosd_prio_complete", True)
 ntfosd_prio_failed = OptionBool("ntfosd", "ntfosd_prio_failed", True)
 ntfosd_prio_disk_full = OptionBool("ntfosd", "ntfosd_prio_disk_full", True)
+ntfosd_prio_quota = OptionBool("ntfosd", "ntfosd_prio_quota", True)
 ntfosd_prio_new_login = OptionBool("ntfosd", "ntfosd_prio_new_login", False)
 ntfosd_prio_warning = OptionBool("ntfosd", "ntfosd_prio_warning", False)
 ntfosd_prio_error = OptionBool("ntfosd", "ntfosd_prio_error", False)
@@ -607,6 +611,7 @@ prowl_prio_pp = OptionNumber("prowl", "prowl_prio_pp", -3)
 prowl_prio_complete = OptionNumber("prowl", "prowl_prio_complete", 0)
 prowl_prio_failed = OptionNumber("prowl", "prowl_prio_failed", 1)
 prowl_prio_disk_full = OptionNumber("prowl", "prowl_prio_disk_full", 1)
+prowl_prio_quota = OptionNumber("prowl", "prowl_prio_quota", 0)
 prowl_prio_new_login = OptionNumber("prowl", "prowl_prio_new_login", -3)
 prowl_prio_warning = OptionNumber("prowl", "prowl_prio_warning", -3)
 prowl_prio_error = OptionNumber("prowl", "prowl_prio_error", -3)
@@ -628,6 +633,7 @@ pushover_prio_pp = OptionNumber("pushover", "pushover_prio_pp", -3)
 pushover_prio_complete = OptionNumber("pushover", "pushover_prio_complete", -1)
 pushover_prio_failed = OptionNumber("pushover", "pushover_prio_failed", -1)
 pushover_prio_disk_full = OptionNumber("pushover", "pushover_prio_disk_full", 1)
+pushover_prio_quota = OptionNumber("pushover", "pushover_prio_quota", -1)
 pushover_prio_new_login = OptionNumber("pushover", "pushover_prio_new_login", -3)
 pushover_prio_warning = OptionNumber("pushover", "pushover_prio_warning", 1)
 pushover_prio_error = OptionNumber("pushover", "pushover_prio_error", 1)
@@ -646,6 +652,7 @@ pushbullet_prio_pp = OptionBool("pushbullet", "pushbullet_prio_pp", False)
 pushbullet_prio_complete = OptionBool("pushbullet", "pushbullet_prio_complete", True)
 pushbullet_prio_failed = OptionBool("pushbullet", "pushbullet_prio_failed", True)
 pushbullet_prio_disk_full = OptionBool("pushbullet", "pushbullet_prio_disk_full", True)
+pushbullet_prio_quota = OptionBool("pushbullet", "pushbullet_prio_quota", True)
 pushbullet_prio_new_login = OptionBool("pushbullet", "pushbullet_prio_new_login", False)
 pushbullet_prio_warning = OptionBool("pushbullet", "pushbullet_prio_warning", False)
 pushbullet_prio_error = OptionBool("pushbullet", "pushbullet_prio_error", False)
@@ -670,6 +677,8 @@ apprise_target_failed = OptionStr("apprise", "apprise_target_failed")
 apprise_target_failed_enable = OptionBool("apprise", "apprise_target_failed_enable", True)
 apprise_target_disk_full = OptionStr("apprise", "apprise_target_disk_full")
 apprise_target_disk_full_enable = OptionBool("apprise", "apprise_target_disk_full_enable", False)
+apprise_target_quota = OptionStr("apprise", "apprise_target_quota")
+apprise_target_quota_enable = OptionBool("apprise", "apprise_target_quota_enable", True)
 apprise_target_new_login = OptionStr("apprise", "apprise_target_new_login")
 apprise_target_new_login_enable = OptionBool("apprise", "apprise_target_new_login_enable", True)
 apprise_target_warning = OptionStr("apprise", "apprise_target_warning")
@@ -693,6 +702,7 @@ nscript_prio_pp = OptionBool("nscript", "nscript_prio_pp", False)
 nscript_prio_complete = OptionBool("nscript", "nscript_prio_complete", True)
 nscript_prio_failed = OptionBool("nscript", "nscript_prio_failed", True)
 nscript_prio_disk_full = OptionBool("nscript", "nscript_prio_disk_full", True)
+nscript_prio_quota = OptionBool("nscript", "nscript_prio_quota", True)
 nscript_prio_new_login = OptionBool("nscript", "nscript_prio_new_login", False)
 nscript_prio_warning = OptionBool("nscript", "nscript_prio_warning", False)
 nscript_prio_error = OptionBool("nscript", "nscript_prio_error", False)
