@@ -110,6 +110,10 @@ class HistoryDB:
                 _ = self.execute("PRAGMA user_version = 4;") and self.execute(
                     "ALTER TABLE history ADD COLUMN archive INTEGER;"
                 )
+            if version < 5:
+                _ = self.execute("PRAGMA user_version = 5;") and self.execute(
+                    "ALTER TABLE history ADD COLUMN time_added INTEGER;"
+                )
 
             HistoryDB.startup_done = True
 
@@ -119,7 +123,7 @@ class HistoryDB:
             try:
                 self.cursor.execute(command, args)
                 return True
-            except:
+            except Exception:
                 error = str(sys.exc_info()[1])
                 if tries > 0 and "is locked" in error:
                     logging.debug("Database locked, wait and retry")
@@ -135,7 +139,7 @@ class HistoryDB:
                     self.close()
                     try:
                         remove_file(HistoryDB.db_path)
-                    except:
+                    except Exception:
                         pass
                     HistoryDB.startup_done = False
                     self.connect()
@@ -149,7 +153,7 @@ class HistoryDB:
                     logging.info("Traceback: ", exc_info=True)
                     try:
                         self.connection.rollback()
-                    except:
+                    except Exception:
                         # Can fail in case of automatic rollback
                         logging.debug("Rollback Failed:", exc_info=True)
             return False
@@ -187,18 +191,19 @@ class HistoryDB:
             "md5sum" TEXT,
             "password" TEXT,
             "duplicate_key" TEXT,
-            "archive" INTEGER
+            "archive" INTEGER,
+            "time_added" INTEGER
         )
         """
         )
-        self.execute("PRAGMA user_version = 4;")
+        self.execute("PRAGMA user_version = 5;")
 
     def close(self):
         """Close database connection"""
         try:
             self.cursor.close()
             self.connection.close()
-        except:
+        except Exception:
             logging.error(T("Failed to close database, see log"))
             logging.info("Traceback: ", exc_info=True)
 
@@ -227,6 +232,11 @@ class HistoryDB:
         logging.info("Removing all jobs with status=%s", status)
         self.execute("""DELETE FROM history WHERE name LIKE ? AND status = ?""", (search, status))
 
+    def mark_as_completed(self, job: str):
+        """Mark a job as completed in the history"""
+        self.execute("""UPDATE history SET status = ? WHERE nzo_id = ?""", (Status.COMPLETED, job))
+        logging.info("[%s] Marked job %s as completed", caller_name(), job)
+
     def get_failed_paths(self, search: Optional[str] = None) -> List[str]:
         """Return list of all storage paths of failed jobs (may contain non-existing or empty paths)"""
         search = convert_search(search)
@@ -293,8 +303,8 @@ class HistoryDB:
         self.execute(
             """INSERT INTO history (completed, name, nzb_name, category, pp, script, report,
             url, status, nzo_id, storage, path, script_log, script_line, download_time, postproc_time, stage_log,
-            downloaded, fail_message, url_info, bytes, duplicate_key, md5sum, password)
-            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""",
+            downloaded, fail_message, url_info, bytes, duplicate_key, md5sum, password, time_added)
+            VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)""",
             t,
         )
         logging.info("Added job %s to history", nzo.final_name)
@@ -418,7 +428,7 @@ class HistoryDB:
         if self.execute("""SELECT script_log FROM history WHERE nzo_id = ?""", (nzo_id,)):
             try:
                 data = ubtou(zlib.decompress(self.cursor.fetchone()["script_log"]))
-            except:
+            except Exception:
                 pass
         return data
 
@@ -540,6 +550,7 @@ def build_history_info(nzo, workdir_complete: str, postproc_time: int, script_ou
         nzo.duplicate_key,
         nzo.md5sum,
         nzo.correct_password,
+        nzo.time_added,
     )
 
 
@@ -556,7 +567,7 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
         parsed_stage_log = []
         try:
             all_stages_lines = lst.split("\r\n")
-        except:
+        except Exception:
             logging.warning(T("Invalid stage logging in history for %s"), item["name"])
             logging.debug("Lines: %s", lst)
             all_stages_lines = []
@@ -564,13 +575,13 @@ def unpack_history_info(item: sqlite3.Row) -> Dict[str, Any]:
         for stage_lines in all_stages_lines:
             try:
                 key, logs = stage_lines.split(":::")
-            except:
+            except Exception:
                 logging.info('Missing key:::logs "%s"', stage_lines)
                 continue
             stage = {"name": key, "actions": []}
             try:
                 stage["actions"] = logs.split(";")
-            except:
+            except Exception:
                 logging.warning(T("Invalid stage logging in history for %s"), item["name"])
                 logging.debug("Logs: %s", logs)
             parsed_stage_log.append(stage)
