@@ -55,7 +55,7 @@ from sabnzbd.misc import (
     get_cpu_name,
     clean_comma_separated_list,
 )
-from sabnzbd.happyeyeballs import happyeyeballs
+from sabnzbd.get_addrinfo import get_fastest_addrinfo
 from sabnzbd.filesystem import (
     real_path,
     globber,
@@ -310,9 +310,6 @@ def set_login_cookie(remove=False, remember_me=False):
     if remove:
         cherrypy.response.cookie["login_cookie"]["expires"] = 0
         cherrypy.response.cookie["login_salt"]["expires"] = 0
-    else:
-        # Notify about new login
-        notifier.send_notification(T("User logged in"), T("User logged in to the web interface"), "new_login")
 
 
 def check_login_cookie():
@@ -679,6 +676,8 @@ class LoginPage:
             set_login_cookie(remember_me=kwargs.get("remember_me", False))
             # Log the success
             logging.info("Successful login from %s", cherrypy.request.remote_label)
+            # Notify about new login
+            notifier.send_notification(T("User logged in"), T("User logged in to the web interface"), "new_login")
             # Redirect
             raise Raiser("/")
         elif kwargs.get("username") or kwargs.get("password"):
@@ -912,6 +911,7 @@ SPECIAL_VALUE_LIST = (
     "selftest_host",
     "ssdp_broadcast_interval",
     "unrar_parameters",
+    "outgoing_nntp_ip",
 )
 SPECIAL_LIST_LIST = (
     "rss_odd_titles",
@@ -1174,7 +1174,7 @@ def handle_server(kwargs, root=None, new_svr=False):
         kwargs["connections"] = "1"
 
     if kwargs.get("enable") == "1":
-        if not happyeyeballs(
+        if not get_fastest_addrinfo(
             host, int_conv(port), int_conv(kwargs.get("timeout"), default=DEF_NETWORKING_TEST_TIMEOUT)
         ):
             return badParameterResponse(T('Server address "%s:%s" is not valid.') % (host, port), ajax)
@@ -2029,6 +2029,7 @@ NOTIFY_OPTIONS = {
         "ncenter_prio_complete",
         "ncenter_prio_failed",
         "ncenter_prio_disk_full",
+        "ncenter_prio_quota",
         "ncenter_prio_warning",
         "ncenter_prio_error",
         "ncenter_prio_queue_done",
@@ -2045,6 +2046,7 @@ NOTIFY_OPTIONS = {
         "acenter_prio_complete",
         "acenter_prio_failed",
         "acenter_prio_disk_full",
+        "acenter_prio_quota",
         "acenter_prio_warning",
         "acenter_prio_error",
         "acenter_prio_queue_done",
@@ -2061,6 +2063,7 @@ NOTIFY_OPTIONS = {
         "ntfosd_prio_complete",
         "ntfosd_prio_failed",
         "ntfosd_prio_disk_full",
+        "ntfosd_prio_quota",
         "ntfosd_prio_warning",
         "ntfosd_prio_error",
         "ntfosd_prio_queue_done",
@@ -2078,6 +2081,7 @@ NOTIFY_OPTIONS = {
         "prowl_prio_complete",
         "prowl_prio_failed",
         "prowl_prio_disk_full",
+        "prowl_prio_quota",
         "prowl_prio_warning",
         "prowl_prio_error",
         "prowl_prio_queue_done",
@@ -2097,6 +2101,7 @@ NOTIFY_OPTIONS = {
         "pushover_prio_complete",
         "pushover_prio_failed",
         "pushover_prio_disk_full",
+        "pushover_prio_quota",
         "pushover_prio_warning",
         "pushover_prio_error",
         "pushover_prio_queue_done",
@@ -2117,6 +2122,7 @@ NOTIFY_OPTIONS = {
         "pushbullet_prio_complete",
         "pushbullet_prio_failed",
         "pushbullet_prio_disk_full",
+        "pushbullet_prio_quota",
         "pushbullet_prio_warning",
         "pushbullet_prio_error",
         "pushbullet_prio_queue_done",
@@ -2141,6 +2147,8 @@ NOTIFY_OPTIONS = {
         "apprise_target_failed_enable",
         "apprise_target_disk_full",
         "apprise_target_disk_full_enable",
+        "apprise_target_quota",
+        "apprise_target_quota_enable",
         "apprise_target_warning",
         "apprise_target_warning_enable",
         "apprise_target_error",
@@ -2164,6 +2172,7 @@ NOTIFY_OPTIONS = {
         "nscript_prio_complete",
         "nscript_prio_failed",
         "nscript_prio_disk_full",
+        "nscript_prio_quota",
         "nscript_prio_warning",
         "nscript_prio_error",
         "nscript_prio_queue_done",
