@@ -28,11 +28,11 @@ import time
 import io
 import shutil
 import functools
+import rarfile
 from typing import Tuple, List, BinaryIO, Optional, Dict, Any, Union, Set
 
 import sabnzbd
 from sabnzbd.encoding import correct_unknown_encoding, ubtou
-import sabnzbd.utils.rarfile as rarfile
 from sabnzbd.misc import (
     format_time_string,
     find_on_path,
@@ -44,6 +44,7 @@ from sabnzbd.misc import (
     build_and_run_command,
     format_time_left,
     is_none,
+    SABRarFile,
 )
 from sabnzbd.filesystem import (
     make_script_path,
@@ -66,7 +67,7 @@ from sabnzbd.filesystem import (
 )
 from sabnzbd.nzbstuff import NzbObject
 import sabnzbd.cfg as cfg
-from sabnzbd.constants import Status, JOB_ADMIN
+from sabnzbd.constants import Status
 
 
 # Regex globals
@@ -105,15 +106,15 @@ def find_programs(curdir: str):
 
     if sabnzbd.MACOS:
         if sabnzbd.MACOSARM64:
-            # M1 (ARM64) versions
-            sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "osx/par2/arm64/par2-turbo")
-            sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "osx/unrar/arm64/unrar")
+            # ARM64 version of unrar
+            sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "macos/unrar/arm64/unrar")
         else:
-            # Regular x64 versions
-            sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "osx/par2/par2-turbo")
-            sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "osx/unrar/unrar")
-        # The 7zip binary is universal2
-        sabnzbd.newsunpack.SEVENZIP_COMMAND = check(curdir, "osx/7zip/7zz")
+            # Regular x64 version
+            sabnzbd.newsunpack.RAR_COMMAND = check(curdir, "macos/unrar/unrar")
+
+        # The par2 and 7zip binary are universal2
+        sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "macos/par2/par2")
+        sabnzbd.newsunpack.SEVENZIP_COMMAND = check(curdir, "macos/7zip/7zz")
 
     if sabnzbd.WINDOWS:
         sabnzbd.newsunpack.PAR2_COMMAND = check(curdir, "win/par2/par2.exe")
@@ -248,7 +249,7 @@ def external_processing(
 
             # Show current line in history
             nzo.set_action_line(T("Running script"), line)
-    except:
+    except Exception:
         logging.debug("Failed script %s, Traceback: ", extern_proc, exc_info=True)
         return "Cannot run script %s\r\n" % extern_proc, -1
 
@@ -368,7 +369,7 @@ def match_ts(file: str) -> Tuple[str, int]:
     try:
         setname = file[: match.start()]
         setname += ".ts"
-    except:
+    except Exception:
         setname = ""
     return setname, num
 
@@ -379,13 +380,13 @@ def clean_up_joinables(names: List[str]):
         if os.path.exists(name):
             try:
                 remove_file(name)
-            except:
+            except Exception:
                 pass
         name1 = name + ".1"
         if os.path.exists(name1):
             try:
                 remove_file(name1)
-            except:
+            except Exception:
                 pass
 
 
@@ -478,7 +479,7 @@ def file_join(nzo: NzbObject, workdir_complete: str, joinables: List[str]) -> Tu
             else:
                 msg = T("[%s] Joined %s files") % (joinable_set, size)
                 nzo.set_unpack_info("Filejoin", msg, setname)
-    except:
+    except Exception:
         msg = sys.exc_info()[1]
         nzo.fail_msg = T("File join of %s failed") % msg
         nzo.set_unpack_info(
@@ -558,7 +559,7 @@ def rar_unpack(nzo: NzbObject, workdir_complete: str, one_folder: bool, rars: Li
                     rarpath, len(rar_sets[rar_set]), one_folder, nzo, rar_set, extraction_path
                 )
                 success = not fail
-            except:
+            except Exception:
                 success = False
                 fail = 1
                 msg = sys.exc_info()[1]
@@ -647,15 +648,14 @@ def rar_extract_core(
     """
     start = time.time()
 
-    logging.debug("rar_extract(): Extractionpath: %s", extraction_path)
+    logging.debug("Extraction path: %s", extraction_path)
+    logging.debug("Found rar version: %s", rarfile.is_rarfile(rarfile_path))
 
     if password:
         password_command = "-p%s" % password
     else:
         password_command = "-p-"
 
-    ############################################################################
-
     if one_folder or cfg.flat_unpack():
         action = "e"
     else:
@@ -667,24 +667,7 @@ def rar_extract_core(
         overwrite = "-o-"  # Disable overwrite
         rename = "-or"  # Auto renaming
 
-    if sabnzbd.WINDOWS:
-        # On Windows, UnRar uses a custom argument parser
-        # See: https://github.com/sabnzbd/sabnzbd/issues/1043
-        # The -scf forces the output to be UTF8
-        command = [
-            RAR_COMMAND,
-            action,
-            "-idp",
-            "-scf",
-            overwrite,
-            rename,
-            "-ai",
-            password_command,
-            rarfile_path,
-            "%s\\" % long_path(extraction_path),
-        ]
-
-    elif RAR_PROBLEM:
+    if RAR_PROBLEM:
         # Use only oldest options, specifically no "-or" or "-scf"
         command = [
             RAR_COMMAND,
@@ -693,10 +676,11 @@ def rar_extract_core(
             overwrite,
             password_command,
             rarfile_path,
-            "%s/" % extraction_path,
+            extraction_path,
         ]
     else:
         # The -scf forces the output to be UTF8
+        # On Windows, specifically remove long path from destination so Unrar handles it
         command = [
             RAR_COMMAND,
             action,
@@ -707,17 +691,17 @@ def rar_extract_core(
             "-ai",
             password_command,
             rarfile_path,
-            "%s/" % extraction_path,
+            clip_path(extraction_path),
         ]
 
-    if cfg.ignore_unrar_dates():
-        command.insert(3, "-tsm-")
-    if not RAR_PROBLEM and (unrar_parameters := cfg.unrar_parameters().strip().split()):
-        for param in unrar_parameters:
-            command.insert(-2, param)
+        if cfg.ignore_unrar_dates():
+            command.insert(3, "-tsm-")
+        if unrar_parameters := cfg.unrar_parameters().split():
+            for param in unrar_parameters:
+                command.insert(-2, param)
 
-    # Get list of all the volumes part of this set
-    logging.debug("Analyzing rar file ... %s found", rarfile.is_rarfile(rarfile_path))
+    # On Windows, UnRar uses a custom argument parser
+    # See: https://github.com/sabnzbd/sabnzbd/issues/1043
     p = build_and_run_command(command, windows_unrar_command=True)
     sabnzbd.PostProcessor.external_process = p
 
@@ -793,11 +777,21 @@ def rar_extract_core(
             requires_kill = True
 
         elif line.startswith("Cannot create"):
-            line2 = p.stdout.readline()
-            if "must not exceed 260" in line2:
-                msg = "%s: %s" % (T("Unpacking failed, path is too long"), line[13:])
-            else:
-                msg = "%s %s" % (T("Unpacking failed, write error or disk is full?"), line[13:])
+            # Check if maybe it can be salvaged
+            line = p.stdout.readline()
+            lines.append(line.strip())
+            # Error is different on Linux and Windows
+            if line.startswith(("Invalid argument", "The filename, directory name, or volume label syntax")):
+                # Read another line
+                line = p.stdout.readline()
+                lines.append(line.strip())
+                # Will it try to correct?
+                if line.startswith("WARNING: Attempting to correct"):
+                    # Great! Let it try
+                    logging.info("Unrar detected invalid filename and is attempting to correct")
+                    continue
+
+            msg = "%s %s" % (T("Unpacking failed, write error or disk is full?"), line)
             nzo.fail_msg = msg
             nzo.set_unpack_info("Unpack", msg, setname)
             fail = 1
@@ -911,7 +905,7 @@ def unseven(nzo: NzbObject, workdir_complete: str, one_folder: bool, sevens: Lis
             for seven in seven_sets[seven_set]:
                 try:
                     remove_file(seven)
-                except:
+                except Exception:
                     logging.warning(T("Deleting %s failed!"), seven)
         new_files.extend(new_files_set)
 
@@ -1070,7 +1064,7 @@ def par2_repair(nzo: NzbObject, setname: str) -> Tuple[bool, bool]:
             else:
                 logging.info("Par verify failed on %s!", parfile)
                 return readd, False
-        except:
+        except Exception:
             msg = sys.exc_info()[1]
             nzo.fail_msg = T("Repairing failed, %s") % msg
             logging.error(T("Error %s while running par2_repair on set %s"), msg, setname)
@@ -1114,7 +1108,7 @@ def par2_repair(nzo: NzbObject, setname: str) -> Tuple[bool, bool]:
                         remove_file(filepath)
                     except OSError:
                         logging.warning(T("Deleting %s failed!"), filepath)
-    except:
+    except Exception:
         msg = sys.exc_info()[1]
         nzo.fail_msg = T("Repairing failed, %s") % msg
         logging.error(T('Error "%s" while running par2_repair on set %s'), msg, setname, exc_info=True)
@@ -1429,7 +1423,7 @@ def create_env(nzo: Optional[NzbObject] = None, extra_env_fields: Dict[str, Any]
                     env["SAB_" + field.upper()] = str(field_value * 1)
                 else:
                     env["SAB_" + field.upper()] = str(field_value)
-            except:
+            except Exception:
                 # Catch key errors
                 pass
 
@@ -1453,7 +1447,7 @@ def create_env(nzo: Optional[NzbObject] = None, extra_env_fields: Dict[str, Any]
                 env["SAB_" + field.upper()] = str(extra_env_fields[field])
             else:
                 env["SAB_" + field.upper()] = ""
-        except:
+        except Exception:
             # Catch key errors
             pass
 
@@ -1474,16 +1468,16 @@ def rar_volumelist(rarfile_path: str, password: str, known_volumes: List[str]) -
     # UnRar is required to read some RAR files
     # RarFile can fail in special cases
     try:
-        zf = rarfile.RarFile(rarfile_path)
+        zf = SABRarFile(rarfile_path)
 
         # setpassword can fail due to bugs in RarFile
         if password:
             try:
                 zf.setpassword(password)
-            except:
+            except Exception:
                 pass
         zf_volumes = zf.volumelist()
-    except:
+    except Exception:
         zf_volumes = []
 
     # Remove duplicates
@@ -1606,7 +1600,7 @@ def unrar_check(rar: str) -> Tuple[int, bool]:
     if rar:
         try:
             version = run_command([rar])
-        except:
+        except Exception:
             return version, original
         original = "Alexander Roshal" in version
 
@@ -1625,7 +1619,7 @@ def sevenzip_check(sevenzip: str) -> str:
             # Example: 7-Zip (z) 21.06 (x64) : Copyright (c) 1999-2021 Igor Pavlov : 2021-11-24
             #          7-Zip (a) 24.03 (x86) : Copyright (c) 1999-2024 Igor Pavlov : 2024-03-23
             return re.search(r"(\d+\.\d+).*Copyright", seven_command_output).group(1)
-        except:
+        except Exception:
             pass
     return ""
 
@@ -1635,7 +1629,7 @@ def par2_turbo_check(par2_path: str) -> bool:
     try:
         if "par2cmdline-turbo" in run_command([par2_path, "-V"]):
             return True
-    except:
+    except Exception:
         pass
     return False
 
@@ -1660,7 +1654,7 @@ def is_sfv_file(myfile: str) -> bool:
             else:
                 # non-ASCII, so not SFV
                 return False
-    except:
+    except Exception:
         # the with-open() went wrong, so not an existing file, so certainly not a SFV file
         return False
 
@@ -1839,7 +1833,7 @@ def pre_queue(nzo: NzbObject, pp, cat):
 
         try:
             p = build_and_run_command(command, env=create_env(nzo, extra_env_fields))
-        except:
+        except Exception:
             logging.debug("Failed script %s, Traceback: ", script_path, exc_info=True)
             return values
 
