@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -32,7 +32,7 @@ import sabnzbd
 import sabnzbd.cfg
 from sabnzbd.constants import DEF_NETWORKING_TIMEOUT, NNTP_BUFFER_SIZE, NTTP_MAX_BUFFER_SIZE
 from sabnzbd.encoding import utob, ubtou
-from sabnzbd.happyeyeballs import AddrInfo
+from sabnzbd.get_addrinfo import AddrInfo
 from sabnzbd.decorators import synchronized, DOWNLOADER_LOCK
 from sabnzbd.misc import int_conv
 
@@ -342,6 +342,20 @@ class NNTP:
             self.sock.settimeout(self.nw.server.timeout)
 
             # Connect
+            if outgoing_nntp_ip := sabnzbd.cfg.outgoing_nntp_ip():
+                try:
+                    self.sock.bind((outgoing_nntp_ip, 0))
+                    socket_info = self.sock.getsockname()
+                    logging.debug(
+                        "%s@%s: Successfully bound to following ip address: %s at following port: %d",
+                        self.nw.thrdnum,
+                        self.nw.server.host,
+                        socket_info[0],
+                        socket_info[1],
+                    )
+                except socket.error:
+                    raise ConnectionError(f"Could not bind to outgoing interface {outgoing_nntp_ip}")
+
             self.sock.connect(self.addrinfo.sockaddr)
 
             # Secured or unsecured?
