@@ -43,7 +43,8 @@ from sabnzbd.filesystem import (
 )
 from sabnzbd.misc import name_to_cat, cat_pp_script_sanitizer
 from sabnzbd.constants import DEFAULT_PRIORITY, VALID_ARCHIVES, AddNzbFileResult
-from sabnzbd.utils import rarfile
+from sabnzbd.misc import SABRarFile
+import rarfile
 
 
 def add_nzbfile(
@@ -169,13 +170,13 @@ def process_nzb_archive_file(
         if zipfile.is_zipfile(path):
             zf = zipfile.ZipFile(path)
         elif rarfile.is_rarfile(path):
-            zf = rarfile.RarFile(path)
+            zf = SABRarFile(path)
         elif sabnzbd.newsunpack.is_sevenfile(path):
             zf = sabnzbd.newsunpack.SevenZip(path)
         else:
             logging.info("File %s is not a supported archive!", filename)
             return AddNzbFileResult.ERROR, []
-    except:
+    except Exception:
         logging.info(T("Cannot read %s"), path, exc_info=True)
         return AddNzbFileResult.RETRY, []
 
@@ -218,14 +219,18 @@ def process_nzb_archive_file(
                             nzo_id=nzo_id,
                             dup_check=dup_check,
                         )
-                    except (sabnzbd.nzbstuff.NzbEmpty, sabnzbd.nzbstuff.NzbRejected):
-                        # Empty or fully rejected
+                    except (
+                        sabnzbd.nzbstuff.NzbEmpty,
+                        sabnzbd.nzbstuff.NzbRejected,
+                        sabnzbd.nzbstuff.NzbPreQueueRejected,
+                    ):
+                        # Empty or fully rejected (including pre-queue rejections)
                         pass
                     except sabnzbd.nzbstuff.NzbRejectToHistory as err:
                         # Duplicate or unwanted extension directed to history
                         sabnzbd.NzbQueue.fail_to_history(err.nzo)
                         nzo_ids.append(err.nzo.nzo_id)
-                    except:
+                    except Exception:
                         # Something else is wrong, show error
                         logging.error(T("Error while adding %s, removing"), name, exc_info=True)
                     finally:
@@ -329,13 +334,16 @@ def process_single_nzb(
         # Malformed or might not be an NZB file
         result = AddNzbFileResult.NO_FILES_FOUND
     except sabnzbd.nzbstuff.NzbRejected:
-        # Rejected as duplicate or by pre-queue script
+        # Rejected as duplicate
         result = AddNzbFileResult.ERROR
+    except sabnzbd.nzbstuff.NzbPreQueueRejected:
+        # Rejected by pre-queue script - should be silently ignored for URL fetches
+        result = AddNzbFileResult.PREQUEUE_REJECTED
     except sabnzbd.nzbstuff.NzbRejectToHistory as err:
         # Duplicate or unwanted extension directed to history
         sabnzbd.NzbQueue.fail_to_history(err.nzo)
         nzo_ids.append(err.nzo.nzo_id)
-    except:
+    except Exception:
         # Something else is wrong, show error
         logging.error(T("Error while adding %s, removing"), filename, exc_info=True)
         result = AddNzbFileResult.ERROR
@@ -407,7 +415,7 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                 try:
                     file_date = datetime.datetime.fromtimestamp(int(element.attrib.get("date")))
                     file_timestamp = int(element.attrib.get("date"))
-                except:
+                except Exception:
                     file_date = datetime.datetime.fromtimestamp(time_now)
                     file_timestamp = time_now
 
@@ -448,7 +456,7 @@ def nzbfile_parser(full_nzb_path: str, nzo):
                             else:
                                 raw_article_db[partnum] = (article_id, segment_size)
                                 file_bytes += segment_size
-                        except:
+                        except Exception:
                             # In case of missing attributes
                             pass
 
