@@ -363,8 +363,9 @@ class NzbFile(TryList):
 
         # Add first article to decodetable, this way we can check
         # if this is maybe a duplicate nzf
-        first_article = self.add_article(raw_article_db.pop(0))
-        first_article.lowest_partnum = True
+        if raw_article_db:
+            first_article = self.add_article(raw_article_db.pop(0))
+            first_article.lowest_partnum = True
 
         if self in nzo.files:
             logging.info("File %s occurred twice in NZB, skipping", self.filename)
@@ -465,7 +466,7 @@ class NzbFile(TryList):
         try:
             logging.debug("Removing article database for %s", self.nzf_id)
             remove_file(os.path.join(self.nzo.admin_path, self.nzf_id))
-        except:
+        except Exception:
             pass
 
     def __getstate__(self):
@@ -522,6 +523,10 @@ class NzbRejected(Exception):
     pass
 
 
+class NzbPreQueueRejected(Exception):
+    pass
+
+
 class NzbRejectToHistory(Exception):
     def __init__(self, nzo, fail_msg):
         self.nzo: NzbObject = nzo
@@ -586,6 +591,7 @@ NzbObjectSaver = (
     "servercount",
     "unwanted_ext",
     "renames",
+    "time_added",
 )
 
 NzoAttributeSaver = ("cat", "pp", "script", "priority", "final_name", "password", "url")
@@ -667,6 +673,7 @@ class NzbObject(TryList):
         self.avg_stamp = 0.0  # Avg age in seconds (calculated from avg_age)
         self.propagation_delay: Optional[float] = None  # Set during parsing
         self.correct_password: Optional[str] = None
+        self.time_added: int = int(time.time())  # When the NZB was added to the queue
 
         # Bookkeeping values
         self.meta = {}
@@ -867,7 +874,7 @@ class NzbObject(TryList):
             accept = int_conv(accept)
             if accept < 1:
                 self.purge_data()
-                raise NzbRejected
+                raise NzbPreQueueRejected
             if accept == 2:
                 raise NzbRejectToHistory(self, T("Pre-queue script marked job as failed"))
 
@@ -879,13 +886,13 @@ class NzbObject(TryList):
                 self.duplicate_check(repeat=True)
             try:
                 pp = int(pq_pp)
-            except:
+            except Exception:
                 pp = None
             if pq_cat:
                 cat = pq_cat
             try:
                 priority = int(pq_priority)
-            except:
+            except Exception:
                 priority = DEFAULT_PRIORITY
             if pq_script and is_valid_script(pq_script):
                 script = pq_script
@@ -1010,7 +1017,7 @@ class NzbObject(TryList):
                     # Remove and add it back after the position of the first rar
                     self.files.remove(lastrarnzf)
                     self.files.insert(firstrarpos + 1, lastrarnzf)
-                except:
+                except Exception:
                     logging.debug("The lastrar swap did not go well")
 
     @synchronized(TRYLIST_LOCK)
@@ -1296,7 +1303,7 @@ class NzbObject(TryList):
                 self.bytes += nzf.bytes
                 self.bytes_tried += nzf.bytes
                 self.bytes_downloaded += nzf.bytes
-        except:
+        except Exception:
             logging.error(T("Error importing %s"), self.final_name)
             logging.info("Traceback: ", exc_info=True)
 
@@ -2089,6 +2096,9 @@ class NzbObject(TryList):
         if not isinstance(self.saved_articles, set):
             # Converted from list to set
             self.saved_articles = set(self.saved_articles)
+        if self.time_added is None:
+            # For backward compatibility with older saved NZOs
+            self.time_added = 0
 
     def __repr__(self):
         return "<NzbObject: filename=%s, bytes=%s, nzo_id=%s>" % (self.filename, self.bytes, self.nzo_id)
