@@ -171,6 +171,7 @@ SKIN_TEXT = {
     "mode": TT("Processing"),  #: Queue page table column header
     "name": TT("Name"),  #: Queue page table column header
     "button-retry": TT("Retry"),  #: Queue page button
+    "button-mark-completed": TT("Mark as Completed & Remove Temporary Files"),  #: History page button
     "eoq-scripts": TT("Scripts"),  #: Queue page table, script selection menu
     "purgeQueue": TT("Purge Queue"),  #: Queue page button
     "purgeQueueConf": TT("Delete all items from the queue?"),  #: Confirmation popup
@@ -544,7 +545,8 @@ SKIN_TEXT = {
     "srv-expire_date": TT("Account expiration date"),
     "srv-explain-expire_date": TT("Warn 5 days in advance of account expiration date."),
     "srv-explain-quota": TT(
-        "Quota for this account, counted from the time it is set. In bytes, optionally follow with K,M,G.<br />Warn when it reaches 0, checked every few minutes."
+        "Quota for this server, counted from the time it is set. In bytes, optionally follow with K,M,G.<br />"
+        "Checked every few minutes. Notification is sent when quota is spent."
     ),
     "srv-retention": TT("Retention time"),  #: Server's retention time in days
     "srv-ssl": TT("SSL"),  #: Server SSL tickbox
@@ -838,6 +840,9 @@ SKIN_TEXT = {
     "Glitter-backToQueue": TT("Send back to queue"),
     "Glitter-purgeOrphaned": TT("Delete All"),
     "Glitter-retryAllOrphaned": TT("Retry all"),
+    "Glitter-clearOrphanWarning": TT(
+        "Are you sure you want to delete all folders in your Temporary Download Folder? This cannot be undone!"
+    ),
     "Glitter-deleteJobAndFolders": TT("Remove NZB & Delete Files"),
     "Glitter-addFromURL": TT("Fetch NZB from URL"),
     "Glitter-addFromFile": TT("Upload NZB"),
@@ -914,6 +919,7 @@ SKIN_TEXT = {
     "wizard-goto": TT("Go to SABnzbd"),  #: Wizard step
     "wizard-exit": TT("Exit SABnzbd"),  #: Wizard EXIT button on first page
     "wizard-start": TT("Start Wizard"),  #: Wizard START button on first page
+    "wizard-test-server-required": TT("Click on Test Server before continuing"),  #: Tooltip for disabled Next button
     "restore-backup": TT("Restore backup"),
     # Special
     "yourRights": TT(
