@@ -259,3 +259,25 @@ class TestHistory:
             history_keys = list(history_job.keys())
             history_keys.sort()
             assert pp_keys == history_keys
+
+    @pytest.mark.usefixtures("run_sabnzbd")
+    def test_add_active_history_duplicate(self):
+        """Verify that add_active_history does not add duplicate entries"""
+        history_db = os.path.join(SAB_CACHE_DIR, DEF_ADMIN_DIR, DB_HISTORY_NAME)
+        with FakeHistoryDB(history_db) as fake_history:
+            fake_history.add_fake_history_jobs(1)
+            jobs, total_items = fake_history.fetch_history()
+            history_job = jobs[-1]
+
+            # Add minimal attributes to create pp-job
+            nzo = mock.Mock()
+            nzo.nzo_id = history_job["nzo_id"]
+            nzo.final_name = "test_add_active_history"
+            nzo.repair, nzo.unpack, nzo.delete = pp_to_opts(choice(list(PP_LOOKUP.keys())))
+            nzo.download_path = os.path.join(os.path.dirname(db.HistoryDB.db_path), "placeholder_downpath")
+            nzo.bytes_downloaded = randint(1024, 1024**4)
+            nzo.unpack_info = {"unpack_info": "placeholder unpack_info line\r\n" * 3}
+            api.add_active_history([nzo], jobs)
+
+            # Make sure the job was not added to the list, a completed entry already exists
+            assert total_items == len(jobs)
