@@ -1,5 +1,5 @@
 #!/usr/bin/python3 -OO
-# Copyright 2007-2024 by The SABnzbd-Team (sabnzbd.org)
+# Copyright 2007-2025 by The SABnzbd-Team (sabnzbd.org)
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -47,23 +47,23 @@ class TestFileFolderNameSanitizer:
 
     @set_platform("win32")
     def test_colon_handling_windows(self):
-        assert filesystem.sanitize_filename("test:aftertest") == "test-aftertest"
-        assert filesystem.sanitize_filename(":") == "-"
-        assert filesystem.sanitize_filename("test:") == "test-"
-        assert filesystem.sanitize_filename("test: ") == "test-"
+        assert filesystem.sanitize_filename("test:aftertest") == "test_aftertest"
+        assert filesystem.sanitize_filename(":") == "_"
+        assert filesystem.sanitize_filename("test:") == "test_"
+        assert filesystem.sanitize_filename("test: ") == "test_"
         # They should act the same
         assert filesystem.sanitize_filename("test:aftertest") == filesystem.sanitize_foldername("test:aftertest")
 
     @set_platform("macos")
     def test_colon_handling_macos(self):
-        assert filesystem.sanitize_filename("test:aftertest") == "aftertest"
-        assert filesystem.sanitize_filename(":aftertest") == "aftertest"
-        assert filesystem.sanitize_filename("::aftertest") == "aftertest"
-        assert filesystem.sanitize_filename(":after:test") == "test"
+        assert filesystem.sanitize_filename("test:aftertest") == "test_aftertest"
+        assert filesystem.sanitize_filename(":aftertest") == "_aftertest"
+        assert filesystem.sanitize_filename("::aftertest") == "__aftertest"
+        assert filesystem.sanitize_filename(":after:test") == "_after_test"
         # Empty after sanitising with macos colon handling
-        assert filesystem.sanitize_filename(":") == "unknown"
-        assert filesystem.sanitize_filename("test:") == "unknown"
-        assert filesystem.sanitize_filename("test: ") == "unknown"
+        assert filesystem.sanitize_filename(":") == "_"
+        assert filesystem.sanitize_filename("test:") == "test_"
+        assert filesystem.sanitize_filename("test: ") == "test_"
 
     @set_platform("linux")
     def test_colon_handling_other(self):
@@ -92,7 +92,7 @@ class TestFileFolderNameSanitizer:
     @set_platform("win32")
     def test_file_illegal_chars_win32(self):
         assert filesystem.sanitize_filename("test" + filesystem.CH_ILLEGAL_WIN + "aftertest") == (
-            "test" + filesystem.CH_LEGAL_WIN + "aftertest"
+            "test" + (len(filesystem.CH_ILLEGAL_WIN) * "_") + "aftertest"
         )
         assert (
             filesystem.sanitize_filename("test" + chr(0) + chr(1) + chr(15) + chr(31) + "aftertest")
@@ -108,25 +108,21 @@ class TestFileFolderNameSanitizer:
 
     @set_platform("linux")
     def test_file_illegal_chars_linux(self):
-        assert filesystem.sanitize_filename("test/aftertest") == "test+aftertest"
-        assert filesystem.sanitize_filename("/test") == "+test"
-        assert filesystem.sanitize_filename("test/") == "test+"
-        assert filesystem.sanitize_filename(r"/test\/aftertest/") == r"+test\+aftertest+"
-        assert filesystem.sanitize_filename("/") == "+"
-        assert filesystem.sanitize_filename("///") == "+++"
-        assert filesystem.sanitize_filename("../") == "..+"
-        assert filesystem.sanitize_filename("../test") == "..+test"
+        assert filesystem.sanitize_filename("test/aftertest") == "test_aftertest"
+        assert filesystem.sanitize_filename("/test") == "_test"
+        assert filesystem.sanitize_filename("test/") == "test_"
+        assert filesystem.sanitize_filename(r"/test\/aftertest/") == r"_test\_aftertest_"
+        assert filesystem.sanitize_filename("/") == "_"
+        assert filesystem.sanitize_filename("///") == "___"
+        assert filesystem.sanitize_filename("../") == ".._"
+        assert filesystem.sanitize_filename("../test") == ".._test"
 
     @set_platform("linux")
     def test_folder_illegal_chars_linux(self):
-        assert filesystem.sanitize_foldername('test"aftertest') == "test'aftertest"
-        assert filesystem.sanitize_foldername("test:") == "test-"
+        assert filesystem.sanitize_foldername('test"aftertest') == "test_aftertest"
+        assert filesystem.sanitize_foldername("test:") == "test_"
         assert filesystem.sanitize_foldername("test<>?*|aftertest") == "test<>?*|aftertest"
 
-    def test_char_collections(self):
-        assert len(filesystem.CH_ILLEGAL) == len(filesystem.CH_LEGAL)
-        assert len(filesystem.CH_ILLEGAL_WIN) == len(filesystem.CH_LEGAL_WIN)
-
     @set_platform("linux")
     def test_legal_chars_linux(self):
         # Illegal on Windows but not on Linux, unless sanitize_safe is active.
@@ -144,20 +140,17 @@ class TestFileFolderNameSanitizer:
     def test_sanitize_safe_linux(self):
         # Set sanitize_safe to on, simulating Windows-style restrictions.
         assert filesystem.sanitize_filename("test" + filesystem.CH_ILLEGAL_WIN + "aftertest") == (
-            "test" + filesystem.CH_LEGAL_WIN + "aftertest"
+            "test" + (len(filesystem.CH_ILLEGAL_WIN) * "_") + "aftertest"
         )
         for index in range(0, len(filesystem.CH_ILLEGAL_WIN)):
-            char_leg = filesystem.CH_LEGAL_WIN[index]
             char_ill = filesystem.CH_ILLEGAL_WIN[index]
-            assert filesystem.sanitize_filename("test" + char_ill * 2 + "aftertest") == (
-                "test" + char_leg * 2 + "aftertest"
-            )
+            assert filesystem.sanitize_filename("test" + char_ill * 2 + "aftertest") == ("test__aftertest")
             # Illegal chars that also get caught by strip() never make it far
             # enough to be replaced by their legal equivalents if they appear
             # on either end of the filename.
             if char_ill.strip():
-                assert filesystem.sanitize_filename("test" + char_ill * 2) == ("test" + char_leg * 2)
-                assert filesystem.sanitize_filename(char_ill * 2 + "test") == (char_leg * 2 + "test")
+                assert filesystem.sanitize_filename("test" + char_ill * 2) == "test__"
+                assert filesystem.sanitize_filename(char_ill * 2 + "test") == "__test"
 
     def test_filename_dot(self):
         # All dots should survive in filenames
@@ -181,15 +174,57 @@ class TestFileFolderNameSanitizer:
         assert filesystem.sanitize_foldername("test.aftertest.") == "test.aftertest"
         assert filesystem.sanitize_foldername("test.aftertest..") == "test.aftertest"
         assert filesystem.sanitize_foldername("test. aftertest. . . .") == "test. aftertest"
-        assert filesystem.sanitize_foldername("/test/this.") == "+test+this"
-        assert filesystem.sanitize_foldername("/test./this.") == "+test.+this"
-        assert filesystem.sanitize_foldername("/test. /this . ") == "+test. +this"
+        assert filesystem.sanitize_foldername("/test/this.") == "_test_this"
+        assert filesystem.sanitize_foldername("/test./this.") == "_test._this"
+        assert filesystem.sanitize_foldername("/test. /this . ") == "_test. _this"
 
     def test_long_foldername(self):
+        # Note: some filesystem can handle up to 255 UTF chars (which is more than 255 bytes) in the foldername,
+        # but we stay on the safe side: max DEF_FILE_MAX bytes
         assert len(filesystem.sanitize_foldername("test" * 100)) == DEF_FOLDER_MAX
         assert len(filesystem.sanitize_foldername("a" * DEF_FOLDER_MAX)) == DEF_FOLDER_MAX
         assert len(filesystem.sanitize_foldername("a" * (DEF_FOLDER_MAX + 1))) == DEF_FOLDER_MAX
 
+        # Adapted from filename tests
+
+        # PART 1: Base cases: Nothing should happen:
+        # normal filename
+        name = "a" * 200
+        sanitizedname = filesystem.sanitize_foldername(name)
+        assert sanitizedname == name
+
+        # Unicode / UTF8 is OK ... as total filename length is not too long
+        name = "BASE" + "你" * 50 + "blabla"
+        sanitizedname = filesystem.sanitize_foldername(name)
+        assert sanitizedname == name
+
+        # PART 2: base truncating
+        name = "BASE" + "a" * 300
+        sanitizedname = filesystem.sanitize_foldername(name)
+        assert len(sanitizedname) <= DEF_FOLDER_MAX
+        assert sanitizedname.startswith("BASEaaaaaaaaaaaaaaa")
+
+        # PART 3: more exotic cases
+
+        # insert NON-ASCII chars, which should stay in place because overall length is no problem
+        name = "aaaa" + 10 * chr(188) + 10 * chr(222) + "bbbb"
+        sanitizedname = filesystem.sanitize_foldername(name)
+        assert sanitizedname == name
+
+        # insert NON-ASCII chars
+        name = "aaaa" + 200 * chr(188) + 200 * chr(222)
+        sanitizedname = filesystem.sanitize_foldername(name)
+        assert (
+            sanitizedname
+            == "aaaa¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼"
+        )
+
+        # Unicode / UTF8 ... total filename length might be too long for certain filesystems
+        name = "BASE" + "你" * 200
+        sanitizedname = filesystem.sanitize_foldername(name)
+        assert sanitizedname.startswith("BASE")
+        assert sanitizedname.endswith("你")
+
     def test_filename_empty_result(self):
         # Nothing remains after sanitizing the filename
         assert filesystem.sanitize_filename("\n") == "unknown"
@@ -253,10 +288,13 @@ class TestFileFolderNameSanitizer:
         sanitizedname = filesystem.sanitize_filename(name)
         assert sanitizedname == name
 
-        # insert NON-ASCII chars, which should get removed because overall length is too long
+        # insert NON-ASCII chars
         name = "aaaa" + 200 * chr(188) + 200 * chr(222) + "bbbb.ext"
         sanitizedname = filesystem.sanitize_filename(name)
-        assert sanitizedname == "aaaabbbb.ext"
+        assert (
+            sanitizedname
+            == "aaaa¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼¼.ext"
+        )
 
         # Unicode / UTF8 ... total filename length might be too long for certain filesystems
         name = "BASE" + "你" * 200 + ".ext"
@@ -288,7 +326,7 @@ class TestSanitizeFiles(ffs.TestCase):
         # The very specific tests of sanitize_filename() are above
         # Here we just want to see that sanitize_files() works as expected
         input_list = [r"c:\test\con.man", r"c:\test\foo:bar"]
-        output_list = [r"c:\test\_con.man", r"c:\test\foo-bar"]
+        output_list = [r"c:\test\_con.man", r"c:\test\foo_bar"]
 
         # Test both the "folder" and "filelist" based calls
         for kwargs in ({"folder": r"c:\test"}, {"filelist": input_list}):
@@ -1091,7 +1129,7 @@ class TestRenamer:
         try:
             # Should fail
             filesystem.renamer(filename, newfilename)
-        except:
+        except Exception:
             pass
         assert os.path.isfile(filename)
         assert not os.path.isfile(newfilename)
@@ -1101,7 +1139,7 @@ class TestRenamer:
         newfilename = os.path.join(dirname, "newsubdir", "newfile.txt")
         try:
             filesystem.renamer(filename, newfilename, create_local_directories=True)
-        except:
+        except Exception:
             pass
         assert not os.path.isfile(filename)
         assert os.path.isfile(newfilename)
@@ -1111,7 +1149,7 @@ class TestRenamer:
         newfilename = os.path.join(dirname, "newsubdir", "deepersubdir", "newfile.txt")
         try:
             filesystem.renamer(filename, newfilename, create_local_directories=True)
-        except:
+        except Exception:
             pass
         assert not os.path.isfile(filename)
         assert os.path.isfile(newfilename)
@@ -1121,7 +1159,7 @@ class TestRenamer:
         newfilename = os.path.join(dirname, "..", "newsubdir", "newfile.txt")
         try:
             filesystem.renamer(filename, newfilename, create_local_directories=True)
-        except:
+        except Exception:
             pass
         assert os.path.isfile(filename)
         assert not os.path.isfile(newfilename)
