@@ -34,84 +34,92 @@ from tests.testhelper import *
 
 @pytest.mark.usefixtures("clean_cache_dir")
 class TestPostProc:
-    # Tests of rar_renamer() (=deobfuscate) against various input directories
-    def test_rar_renamer(self):
-        # Function to deobfuscate one directory with rar_renamer()
-        def deobfuscate_dir(sourcedir, expected_filename_matches):
-            # We create a workingdir inside the sourcedir, because the filenames are really changed
-            workingdir = os.path.join(sourcedir, "workingdir")
+    # Helper function for rar_renamer tests
+    def _deobfuscate_dir(self, sourcedir, expected_filename_matches):
+        """Function to deobfuscate one directory with rar_renamer()"""
+        # We create a workingdir inside the sourcedir, because the filenames are really changed
+        workingdir = os.path.join(SAB_CACHE_DIR, "workingdir_test_rar_renamer")
 
-            # if workingdir is still there from previous run, remove it:
-            if os.path.isdir(workingdir):
-                try:
-                    shutil.rmtree(workingdir)
-                except PermissionError:
-                    pytest.fail("Could not remove existing workingdir %s for rar_renamer" % workingdir)
-
-            # create a fresh copy
-            try:
-                shutil.copytree(sourcedir, workingdir)
-            except Exception:
-                pytest.fail("Could not create copy of files for rar_renamer")
-
-            # And now let the magic happen:
-            nzo = mock.Mock()
-            nzo.final_name = "somedownloadname"
-            nzo.download_path = workingdir
-            number_renamed_files = postproc.rar_renamer(nzo)
-
-            # run check on the resulting files
-            if expected_filename_matches:
-                for filename_match in expected_filename_matches:
-                    if len(globber_full(workingdir, filename_match)) != expected_filename_matches[filename_match]:
-                        pytest.fail("Failed filename_match %s in %s" % (filename_match, workingdir))
-
-            # Remove workingdir again
+        # if workingdir is still there from previous run, remove it:
+        if os.path.isdir(workingdir):
             try:
                 shutil.rmtree(workingdir)
-            except Exception:
+            except PermissionError:
                 pytest.fail("Could not remove existing workingdir %s for rar_renamer" % workingdir)
 
-            return number_renamed_files
+        # create a fresh copy
+        try:
+            shutil.copytree(sourcedir, workingdir)
+        except Exception:
+            pytest.fail("Could not create copy of files for rar_renamer")
 
-        # obfuscated, single rar set
+        # And now let the magic happen:
+        nzo = mock.Mock()
+        nzo.final_name = "somedownloadname"
+        nzo.download_path = workingdir
+        number_renamed_files = postproc.rar_renamer(nzo)
+
+        # run check on the resulting files
+        if expected_filename_matches:
+            for filename_match in expected_filename_matches:
+                if len(globber_full(workingdir, filename_match)) != expected_filename_matches[filename_match]:
+                    pytest.fail("Failed filename_match %s in %s" % (filename_match, workingdir))
+
+        # Remove workingdir again
+        try:
+            shutil.rmtree(workingdir)
+        except Exception:
+            pytest.fail("Could not remove existing workingdir %s for rar_renamer" % workingdir)
+
+        return number_renamed_files
+
+    def test_rar_renamer_obfuscated_single_rar_set(self):
+        """Test rar_renamer with obfuscated single rar set"""
         sourcedir = os.path.join(SAB_DATA_DIR, "obfuscated_single_rar_set")
         # Now define the filematches we want to see, in which amount ("*-*-*-*-*" are the input files):
         expected_filename_matches = {"*part007.rar": 1, "*-*-*-*-*": 0}
-        assert deobfuscate_dir(sourcedir, expected_filename_matches) == 7
+        assert self._deobfuscate_dir(sourcedir, expected_filename_matches) == 7
 
-        # obfuscated, two rar sets
+    def test_rar_renamer_obfuscated_two_rar_sets(self):
+        """Test rar_renamer with obfuscated two rar sets"""
         sourcedir = os.path.join(SAB_DATA_DIR, "obfuscated_two_rar_sets")
         expected_filename_matches = {"*part007.rar": 2, "*part009.rar": 1, "*-*-*-*-*": 0}
-        assert deobfuscate_dir(sourcedir, expected_filename_matches) == 16
+        assert self._deobfuscate_dir(sourcedir, expected_filename_matches) == 16
 
-        # obfuscated, but not a rar set
+    def test_rar_renamer_obfuscated_but_no_rar(self):
+        """Test rar_renamer with obfuscated files that are not rar sets"""
         sourcedir = os.path.join(SAB_DATA_DIR, "obfuscated_but_no_rar")
         expected_filename_matches = {"*.rar": 0, "*-*-*-*-*": 6}
-        assert deobfuscate_dir(sourcedir, expected_filename_matches) == 0
+        assert self._deobfuscate_dir(sourcedir, expected_filename_matches) == 0
 
+    def test_rar_renamer_single_rar_set_missing_first_rar(self):
+        """Test rar_renamer with single rar set missing first rar"""
         # One obfuscated rar set, but first rar (.part1.rar) is missing
         sourcedir = os.path.join(SAB_DATA_DIR, "obfuscated_single_rar_set_missing_first_rar")
         # single rar set (of 6 obfuscated rar files), so we expect renaming
         # thus result must 6 rar files, and 0 obfuscated files
         expected_filename_matches = {"*.rar": 6, "*-*-*-*-*": 0}
         # 6 files should have been renamed
-        assert deobfuscate_dir(sourcedir, expected_filename_matches) == 6
+        assert self._deobfuscate_dir(sourcedir, expected_filename_matches) == 6
 
+    def test_rar_renamer_double_rar_set_missing_rar(self):
+        """Test rar_renamer with two rar sets where some rars are missing"""
         # Two obfuscated rar sets, but some rars are missing
         sourcedir = os.path.join(SAB_DATA_DIR, "obfuscated_double_rar_set_missing_rar")
         # Two sets, missing rar, so we expect no renaming
         # thus result should be 0 rar files, and still 8 obfuscated files
         expected_filename_matches = {"*.rar": 0, "*-*-*-*-*": 8}
         # 0 files should have been renamed
-        assert deobfuscate_dir(sourcedir, expected_filename_matches) == 0
+        assert self._deobfuscate_dir(sourcedir, expected_filename_matches) == 0
 
+    def test_rar_renamer_fully_encrypted_and_obfuscated(self):
+        """Test rar_renamer with fully encrypted and obfuscated rar set"""
         # fully encrypted rar-set, and obfuscated rar names
         sourcedir = os.path.join(SAB_DATA_DIR, "fully_encrypted_and_obfuscated_rars")
         # SABnzbd cannot do anything with this, so we expect no renaming
         expected_filename_matches = {"*.rar": 0, "*-*-*-*-*": 6}
         # 0 files should have been renamed
-        assert deobfuscate_dir(sourcedir, expected_filename_matches) == 0
+        assert self._deobfuscate_dir(sourcedir, expected_filename_matches) == 0
 
     @pytest.mark.parametrize("category", ["testcat", "Default", None])
     @pytest.mark.parametrize("has_jobdir", [True, False])  # With or without a job dir
